Module clustering

this module contains helpers that wrap the a k-means crate to perform clustering on the data without having to choose an exact number of clusters.

Instead, you provide the minimum and maximum number of clusters you want to try, and we’ll use one of a range of methods to determine the optimal number of clusters.

References:

Structs

AnalysisArray
ClusteringHelper
EntryPoint
Finished
Initialized
NotInitialized

Enums

ClusteringMethod
KOptimal

Functions

convert_to_array
Convert a vector of Analyses into a 2D array