this module contains helpers that wrap the a k-means crate to perform clustering on the data without having to choose an exact number of clusters.
Instead, you provide the minimum and maximum number of clusters you want to try, and we’ll use one of a range of methods to determine the optimal number of clusters.
References:
- The gap statistic R. Tibshirani, G. Walther, and T. Hastie (Standford University, 2001)
- The Davies-Bouldin index wikipedia
Structs
Enums
Functions
- convert_
to_ array - Convert a vector of Analyses into a 2D array